import ctypes
import os

absolute_path = os.path.dirname(__file__)
absolute_path_ubuntu = absolute_path+ "/lib/library.so"
absolute_path_windows = absolute_path+ "/lib/library.dll"

try:
# # Load the shared library
    lib = ctypes.CDLL(absolute_path_windows)
except:
    lib = ctypes.CDLL(absolute_path_ubuntu)

get_community_assignment = lib.get_community_assignment
get_community_assignment.restype = ctypes.POINTER(ctypes.c_int)

def get_community(nodes, edges):

    arr = (ctypes.c_int * (len(edges)*2))()
    for i,[u,v] in enumerate(edges):
        arr[(i*2)] = u
        arr[i*2+1] = v
    
    nrows = len(edges)
    nodeCount = len(nodes)

    res = get_community_assignment(
        arr,
        ctypes.c_int(nrows),
        ctypes.c_int(nodeCount))
    
    
    res = [res[i] for i in range(len(nodes))]
    
    return res







class NotListException(Exception):
    def __repr__(self, data) :
        return f"{data} is not a valid list"

class Not2DListException(Exception):
    def __repr__(self, data) :
        return f"{data} is not a valid 2d list"

class NotAnEdgeException(Exception):
    def __repr__(self, data) :
        return f"{data} is not a valid edge"

class NodeNotExistException(Exception):
    def __repr__(self, data) :
        return f"Node {data} is not Exist in node List"

class GraphNotCreatedException(Exception):
    def __repr__(self, data) :
        return f"Graph is not created."


from setuptools import setup, Extension
from age_community_detection import VERSION

with open("README.md", "r", encoding='utf8') as fh:
    long_description = fh.read()

setup(
    name             = 'apache-age-community-detection',
    version          = VERSION.VERSION,
    description      = 'Detection of Community by maximizing modularity',
    long_description=long_description,
    long_description_content_type="text/markdown",
    author           = 'Moontasir Mahmood',
    author_email     = 'moontasir042@gmail.com',
    url              = 'https://github.com/Munmud/Community-Detection-Modularity',
    license          = 'Apache2.0',
    install_requires = [],
    packages         = ['age_community_detection'],
    package_data={'age_community_detection': ['lib/*.so', 'lib/*.dll']},
    keywords         = ['Community-Detection', 'Modularity', 'Reichardt and Bornholdt','Newman', 'partition network', 'k means cluster'],
    python_requires  = '>=3.9',
    classifiers      = [
        'Programming Language :: Python :: 3.9'
    ]
)